@@ -1,5 +1,6 @@
+from .__about__ import __version__
 from ._app import run
 from .blockchar_stream import BlockCharStream
 from .braille_stream import BrailleStream
 
-__all__ = ["BrailleStream", "BlockCharStream", "run"]
+__all__ = ["BrailleStream", "BlockCharStream", "run", "__version__"]
